@@ -48,7 +48,6 @@ class SseqChart:
         self.name = name
         assert num_gradings >= 2
         self.num_gradings = num_gradings
-        self._initialized = True
 
         self._agent : Any = None
         self._batched_messages : List[Dict[str, Any]] = []
@@ -139,14 +138,15 @@ class SseqChart:
     def to_json(self) -> Dict[str, Any]:
         return dict(
             type=type(self).__name__,
+            uuid=self.uuid,
             name=self.name,
             initial_x_range=self._initial_x_range,
             initial_y_range=self._initial_y_range,
             x_range=self._x_range,
             y_range=self._y_range,
             num_gradings=self.num_gradings,
-            x_degree=self.x_projection,
-            y_degree=self.y_projection,
+            x_projection=self.x_projection,
+            y_projection=self.y_projection,
             page_list=self.page_list,
             classes=list(self._classes.values()),
             edges=list(self._edges.values())
@@ -155,13 +155,11 @@ class SseqChart:
 
     @staticmethod
     def from_json(json_obj : Dict[str, Any]) -> "SseqChart":
-        result = SseqChart._from_json_helper(**json_obj)
-        return result
+        chart = SseqChart(json_obj.pop("name"), json_obj.pop("num_gradings"))
+        chart._from_json_helper(**json_obj)
+        return chart
 
-    @staticmethod
-    def _from_json_helper(
-        name : str, 
-        num_gradings : int,
+    def _from_json_helper(self,
         type : str,
         uuid : str,
         page_list : List[Tuple[int, int]],
@@ -173,22 +171,20 @@ class SseqChart:
         y_projection : Tuple[int, ...],
         classes : List[ChartClass],
         edges : List[ChartEdge]
-    )  -> "SseqChart":
+    ):
         assert type == SseqChart.__name__
-        chart = SseqChart(name, num_gradings)
-        chart._uuid = uuid
-        chart._page_list = page_list
-        chart._initial_x_range = initial_x_range
-        chart._initial_y_range = initial_y_range
-        chart._x_range = x_range
-        chart._y_range = y_range
-        chart._x_projection = x_projection
-        chart._y_projection = y_projection
+        self._uuid = uuid
+        self._page_list = page_list
+        self._initial_x_range = initial_x_range
+        self._initial_y_range = initial_y_range
+        self._x_range = x_range
+        self._y_range = y_range
+        self._x_projection = x_projection
+        self._y_projection = y_projection
         for c in classes:
-            chart._commit_class(c)
+            self._commit_class(c)
         for e in edges:
-            chart._commit_edge(e)
-        return chart
+            self._commit_edge(e)
         
         
     def add_class(self, *degree : int) -> ChartClass:
@@ -280,8 +276,8 @@ class SseqChart:
         """ Common logic between add_structline, add_differential, add_extension, and deserialization."""
         e._sseq = self
         self._edges[e.uuid] = e
-        e.source = self._classes[e._source_uuid]
-        e.target = self._classes[e._target_uuid]
+        e._source = self._classes[e._source_uuid]
+        e._target = self._classes[e._target_uuid]
         e.source.edges.append(e)
         e.target.edges.append(e)
         self._add_create_message(e)
