@@ -37,7 +37,6 @@ class ChartClass:
         self._visible = PageProperty(True, parent=self)
         self._x_nudge = PageProperty(0, parent=self)
         self._y_nudge = PageProperty(0, parent=self)
-        self._dom_content = SignalDict({}, parent=self)
         self._user_data = SignalDict({}, parent=self)
 
     def _needs_update(self):
@@ -49,9 +48,9 @@ class ChartClass:
         degree = json.pop("degree")
         idx = json.pop("idx")
         c = ChartClass(degree, idx)
-        return c._from_json_helper(**json)
+        c._from_json_helper(**json)
+        return c
 
-    @staticmethod
     def _from_json_helper(self,     
         uuid : UUID_str,
         name : PagePropertyOrValue[str],
@@ -65,9 +64,8 @@ class ChartClass:
         border_color : PagePropertyOrValue[Color],
         border_thickness : PagePropertyOrValue[float],
         foreground_color : PagePropertyOrValue[Color],
-        dom_content : Dict[str, Union[str, PageProperty[str]]],
         user_data : Dict[str, Any] = None
-    ) -> "ChartClass":
+    ):
         self._uuid = uuid
         self._max_page = max_page
         # Type checker has difficulty with PagePropertyOrValue and the typing of ensure_page_property.
@@ -82,7 +80,6 @@ class ChartClass:
         self._x_nudge = cast(PageProperty[float], ensure_page_property(x_nudge, parent=self))
         self._y_nudge = cast(PageProperty[float], ensure_page_property(y_nudge, parent=self))
 
-        self._dom_content = SignalDict(dom_content, parent=self) # type: ignore
         self._user_data = SignalDict(user_data, parent=self) # type: ignore
 
     def to_json(self) -> Dict[str, Any]:
@@ -102,7 +99,6 @@ class ChartClass:
             visible=self.visible,
             x_nudge=self.x_nudge,
             y_nudge=self.y_nudge,
-            dom_content=self.dom_content,
             user_data=self.user_data
         )
 
@@ -281,11 +277,6 @@ class ChartClass:
         """ The y displacement of the class from its default position. """
         return self._y_nudge
 
-    @property
-    def dom_content(self) -> SignalDict[Union[str, PageProperty[str]]]:
-        """ A dictionary with extra fields that are used for purposes defined by the display. All data added must be serializable. """ 
-        return self._dom_content
-
     @property
     def user_data(self) -> SignalDict[Any]:
         """ Miscellaneous extra data that the user wants to add. All data added must be serializable. """
