@@ -24,8 +24,8 @@ class ChartEdge(ABC):
         self._sseq : SseqChart
         self._source_uuid = source_uuid
         self._target_uuid = target_uuid
-        self.source : ChartClass
-        self.target : ChartClass        
+        self._source : ChartClass
+        self._target : ChartClass        
         self._uuid = str(uuid4())
         self._user_data : SignalDict[Any] = SignalDict({}, parent=self) # type: ignore
 
@@ -79,6 +79,16 @@ class ChartEdge(ABC):
         """ A unique id for the edge. For internal use. """
         return self._uuid
 
+    @property
+    def source(self) -> "ChartEdge":
+        """ The start class of the edge. (All edges must be directed.) """
+        return self._source
+
+    @property
+    def target(self) -> "ChartEdge":
+        """ The end class of the edge. (All edges must be directed.) """
+        return self._target
+
     def _from_json_helper(self,
         type : Optional[str], 
         uuid : UUID_str,
@@ -131,6 +141,8 @@ class ChartStructline(ChartEdge):
             dash_pattern=self.dash_pattern,
             line_width=self.line_width,
             bend=self.bend,
+            start_tip=self.start_tip,
+            end_tip=self.end_tip,
             visible=self.visible,
             user_data=self._user_data
         )
@@ -353,7 +365,7 @@ class SinglePageChartEdge(ChartEdge):
         )
 
 
-class ChartDifferential(ChartEdge):
+class ChartDifferential(SinglePageChartEdge):
     """ A ChartDifferential is an edge used to represent the behavior of the differential on the spectral sequence. 
         A chart differential will appear on page_range (<page>, <max_differential_length>) if <page> <= differential.page <= <max_differential_length>
         and if both the source and target of the differential appear on page <page>.
@@ -368,7 +380,7 @@ class ChartDifferential(ChartEdge):
             page=self.page
         )
 
-class ChartExtension(ChartEdge):
+class ChartExtension(SinglePageChartEdge):
     """ A ChartExtension is an edge used to represent extensions in the spectral sequence. 
         Generally extensions represent the same sort of algebraic structure as the structlines.
         A chart extension will appear on page_range (<page>, <max_differential_length>) if <page> == infinity
