@@ -93,12 +93,15 @@ class PageProperty(Generic[T]):
         return self._values == other._values
 
     def to_json(self) -> Dict[str, Any]:
-        return {"type" : "PageProperty", "values" : self._values }
+        if len(self._values) == 1:
+            return self._values[0][1]
+        else:
+            return {"type" : "PageProperty", "values" : self._values }
     
     @staticmethod
     def from_json(json_obj : Dict[str, Any]) -> "PageProperty[Any]":
         result : PageProperty[Any] = PageProperty(None)
-        result._values = [cast(Tuple[int, Any], tuple(x)) for x in json_obj["data"]]
+        result._values = [cast(Tuple[int, Any], tuple(x)) for x in json_obj["values"]]
         return result
 
 S = TypeVar('S')
